@@ -7,6 +7,6 @@ from urllib.parse import urlparse
 from .model import Visit
 
 
-def demo_visit(visits: List[Visit]):
+def demo_visit(visits: List[Visit]) -> None:
     print("Demo: Your most common sites....")
     pprint(Counter(map(lambda v: urlparse(v.url).netloc, visits)).most_common(10))
